@@ -37,7 +37,8 @@ class GenericPublisher(object):
                                          port=self.config.port,
                                          userid=self.config.user,
                                          password=self.config.password,
-                                         virtual_host=self.config.vhost)
+                                         virtual_host=self.config.vhost,
+                                         ssl=self.config.ssl)
 
     def disconnect(self):
         if self.connection:
